import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import constructs._jsii
import ros_cdk_core._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@alicloud/ros-cdk-redis",
    "1.0.12",
    __name__[0:-6],
    "ros-cdk-redis@1.0.12.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
